.. currentmodule:: sardana.pool.poolzerodexpchannel

.. _sardana-0d-api:

=============================
0D channel API reference
=============================

.. todo:: document 0D channel API reference

.. seealso:: 
    
    :ref:`sardana-0d-overview`
        the 0D experiment channel overview 
    
    :class:`~sardana.tango.pool.ZeroDExpChannel.ZeroDExpChannel`
        the 0D experiment channel tango device :term:`API`

..    :class:`~sardana.pool.poolzerodexpchannel.Pool0DExpChannel`
..        the 0D experiment channel class :term:`API`
